Struct dharitri_wasm_module_pause::AbiProvider
source · pub struct AbiProvider {}Trait Implementations
sourceimpl ContractAbiProvider for AbiProvider
impl ContractAbiProvider for AbiProvider
type BigUint = BigUintUncallable
type BigUint = BigUintUncallable
The generated ABI generation code uses the same types as the contract to provide
TypeAbis to endpoints.
This associated type allows Self::BigUint to also make sense in the ABI context.type BigInt = BigIntUncallable
type BigInt = BigIntUncallable
The generated ABI generation code uses the same types as the contract to provide
TypeAbis to endpoints.
This associated type allows Self::BigInt to also make sense in the ABI context.type Storage = UncallableApi
type Storage = UncallableApi
The generated ABI generation code uses the same types as the contract to provide
TypeAbis to endpoints.
It sometimes references the contract storage manager type in with storage mappers,
as for example in SingleValueMapper<Self::Storage, i32>.type SendApi = UncallableApi
type SendApi = UncallableApi
The generated ABI generation code uses the same types as the contract to provide
TypeAbis to endpoints.
It is referenced by contract calls in general,
as for example in AsyncCall<Self::Send>.sourcefn abi() -> ContractAbi
fn abi() -> ContractAbi
Associated function that provides the contract or module ABI.
Since ABI generation is static, no state from the contract is required.