pub trait PauseModule: ContractBase + Sized {
// Required methods
fn is_paused(&self) -> bool;
fn set_paused(&self, paused: bool);
// Provided methods
fn not_paused(&self) -> bool { ... }
fn pause_endpoint(&self) -> SCResult<()> { ... }
fn unpause_endpoint(&self) -> SCResult<()> { ... }
}Expand description
Standard smart contract module that, when added to a smart contract, offers pausability.
It provides a flag that contracts can use to check if owner decided to pause the entire contract. Use the features module for more granular on/off switches.
It offers:
- an endpoint where the owner can pause/unpause contract
- a method to check if contract is paused or not
Required Methods
Provided Methods
fn not_paused(&self) -> bool
fn pause_endpoint(&self) -> SCResult<()>
fn unpause_endpoint(&self) -> SCResult<()>
Object Safety
This trait is not object safe.